@@ -93,15 +93,24 @@ class ProcessingStudy(EntityType):
     description = RichString()
 
 
-class in_study(RelationDefinition):
+class _in_study(RelationDefinition):
+    __abstract__ = True
     __permissions__ = rel_perms_of_object
-    subject = ('Run', 'RunChain')
+    name = 'in_study'
     object  = 'ProcessingStudy'
     cardinality = '?*'
     inlined = True
     composite = 'object'
 
 
+class run_in_study(_in_study):
+    subject = 'Run'
+
+
+class runchain_in_study(_in_study):
+    subject = 'RunChain'
+
+
 class ParameterDefinition(EntityType):
     __permissions__ = {
         'read':   ('managers', 'users', 'guests'),
